
----------------------------------------------------------------------------------------------------------------
-- global variables

next_time_redo = 0
is_game_over = 0

is_player_in_water = false

----------------------------------------------------------------------------------------------------------------
-- load and save

function callSaveGame()
	saveGame()
	next_time_redo = getTime() + 1000
end

function callLoadGame()
	loadGame()
	is_game_over = 0
	is_player_in_water = false
	next_time_redo = getTime() + 1000
end

----------------------------------------------------------------------------------------------------------------

Game = {

	sound_main_music = 0,
	model_delta_wing = 0,
	time_main_music = 0,

	--------------------------------------------------------

	init = function()
		setFogColor(180,200,255)
		sound_main_music = loadSound('sound/ocean.ogg')		
		fall_in_water_sprite = load2DSprite('images/fall_in_water.png')
		model_delta_wing = load3DModel('models/obj_delta_wing/delta_wing.obj')
		time_main_music = getTime()
		--initActiveObjects('Gun','MagicSphere','Inhabitant','Pipe','Path1','Path2','DormRoom','Market')
		--setPlayerPositionReal(5640, 320, 20)
		setPlayerPositionReal(0, 1000.0, 0)
	end,
	
	--------------------------------------------------------

	uninit = function()
		unload2DSprite(fall_in_water_sprite)
		unload3DModel(model_delta_wing)
	end,
	
	--------------------------------------------------------
	
	manage = function()
	
		if getTime() > time_main_music then
			time_main_music = getTime() + 500000
			playSound(sound_main_music)
			setSoundVolume(sound_main_music, 0.0)
		end
		
		local xpl,ypl,zpl = getPlayerPositionReal()
		if ypl > 300.0 and isPlayingSound(sound_main_music) then 
			setSoundVolume(sound_main_music, 0.0)
		else
			setSoundVolume(sound_main_music, 1.0 - ypl/300.0)
		end
		
		if getKeyNoRepeat('a') then
			setEditorMode(not isEditorMode())
		end
	
	end,
	
	--------------------------------------------------------
	
	draw3D = function()
	
		if not isEditorMode() then
		
			x, y, z = getPlayerPositionReal()
			
			-- fall into the water
			if y < -0.0 and not is_player_in_water then
				--playSound(sound_splash)
				is_player_in_water = true
			end
			
			if getKey('l') then
				callLoadGame()
			end
			
			-- flying
			if getKey('r') then
				speedx, speedy, speedz = getPlayerSpeed()
				setPlayerSpeed(speedx, 1.0, speedz)
			end
			
			local is_left_click, is_middle_click, is_right_click, is_wheel_up, is_wheel_down, pos_x, pos_y = getMouseInfos()
			if is_left_click then
					speedx, speedy, speedz = getPlayerSpeed()
					if speedy < -0.0 then
						setCurrentPositionReal(getPlayerPositionReal())
						local angle_x, angle_y, dist = getCameraAngleAndDistance()
						rotatePosition(0,angle_y,0)
						draw3DModel(model_delta_wing)
						if speedx > 0.0 then
							setPlayerSpeed(6.0, -0.2, speedz)
						else
							setPlayerSpeed(speedx, -0.2, speedz)
						end
					end
				end
			
		end
	end,
	
	--------------------------------------------------------
	
	draw2D = function()
	
		local win_width, win_height = getWindowSize()

		if not isEditorMode() then
				
			if is_player_in_water then
				setPlayerMovementNone()
				setColor(255,255,255,255)
				if not isEditorMode() then
					draw2DSprite(fall_in_water_sprite, win_width/2 - 128, win_height/2 - 128)
				end
				local px,py,pz = getPlayerPositionReal()
				setPlayerPositionReal(px, -10.0, pz)
			end
			
		end
	end
}
